@@ -852,7 +852,7 @@ class RedisRoot:
 
     def get(self, django_model, return_dict=False, **filters):
         redis_model = self.get_or_create_redis_model_from_django_model(django_model)
-        result = get_by_redis_model(redis_model, return_dict=False, **filters)
+        result = self.get_by_redis_model(redis_model, return_dict=False, **filters)
         return result
 
     def order(self, instances, field_name):
